/*
 * Name:    mx_heap.c
 *
 * Purpose: MX functions to check the heap for corruption.
 *
 *          This functionality is not available on all platforms.  Even if
 *          it is, it may not work reliably if the program is in the process
 *          of crashing when this function is invoked.
 *
 * Author:  William Lavender
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 2004 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>

#include "mx_osdef.h"

#include "mx_util.h"

#if defined( OS_WIN32 ) && defined( _DEBUG )

MX_EXPORT int
mx_is_valid_heap_pointer( void *pointer )
{
	return _CrtIsValidHeapPointer( pointer );
}

#else

MX_EXPORT int
mx_is_valid_heap_pointer( void *pointer )
{
	return TRUE;
}

#endif

/*-------------------------------------------------------------------------*/

#if defined( OS_WIN32 ) && defined( _DEBUG )

MX_EXPORT int
mx_heap_check( void )
{
	return _CrtCheckMemory();
}

#else

MX_EXPORT int
mx_heap_check( void )
{
	return TRUE;
}

#endif

