/*
 * Name:     n_spec.h
 *
 * Purpose:  Header file for client interface to a Spec server.
 *
 * Author:   William Lavender
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 2004 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __N_SPEC_H__
#define __N_SPEC_H__

#include "mx_socket.h"

/* ===== Spec server record data structures ===== */

typedef struct {
	MX_RECORD *record;

	char hostname[ MXU_HOSTNAME_LENGTH + 1 ];
	int port;

	MX_SOCKET *socket;
} MX_SPEC_SERVER;

/* Define all of the client interface functions. */

MX_API mx_status_type mxn_spec_server_create_record_structures(
							MX_RECORD *record );
MX_API mx_status_type mxn_spec_server_finish_record_initialization(
							MX_RECORD *record );
MX_API mx_status_type mxn_spec_server_open( MX_RECORD *record );
MX_API mx_status_type mxn_spec_server_close( MX_RECORD *record );
MX_API mx_status_type mxn_spec_server_resynchronize( MX_RECORD *record );

extern MX_RECORD_FUNCTION_LIST mxn_spec_server_record_function_list;

extern long mxn_spec_server_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxn_spec_server_rfield_def_ptr;

#define MXN_SPEC_SERVER_STANDARD_FIELDS \
  {-1, -1, "hostname", MXFT_STRING, NULL, 1, { MXU_HOSTNAME_LENGTH }, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_SPEC_SERVER, hostname), \
	{sizeof(char)}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {-1, -1, "port", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_SPEC_SERVER, port), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}

#endif /* __N_SPEC_H__ */

